# Dataset package

```{eval-rst}
.. automodule:: sec_certs.dataset
    :no-members:
```

This documentation doesn't provide full API reference for all members of `dataset` package. Instead, it concentrates on the Dataset that are immediately exposed to the users.
Namely, we focus on `CCDataset`, `FIPSDataset`, `ProtectionProfileDataset` and their abstract base class `Dataset`.

```{tip}
The examples related to this package can be found in the [common criteria notebook](./../notebooks/examples/cc.ipynb),
the [protection profile notebook](./../notebooks/examples/protection_profiles.ipynb), and the [fips notebook](./../notebooks/examples/fips.ipynb).
```

## Base Dataset

```{eval-rst}
.. currentmodule:: sec_certs.dataset.dataset
.. autoclass:: Dataset
    :members:
```

## CCDataset

```{eval-rst}
.. currentmodule:: sec_certs.dataset
.. autoclass:: CCDataset
    :members:
```

## ProtectionProfileDataset

```{eval-rst}
.. currentmodule:: sec_certs.dataset
.. autoclass:: ProtectionProfileDataset
    :members:
```

## FIPSDataset

```{eval-rst}
.. currentmodule:: sec_certs.dataset
.. autoclass:: FIPSDataset
    :members:
```
